==> pear_0.1-1.tar.gz: pear/data/fraser.R <==
"fraser"<-
structure(.Data = c(485, 1150, 4990, 6130, 4780, 3960, 2160, 1530, 1060, 761, 
	516, 710, 570, 984, 2690, 8280, 6480, 5990, 3930, 1760, 1010, 736, 1050,
	787, 906, 2100, 5730, 7140, 6530, 3720, 2140, 1970, 1760, 1080, 886, 
	749, 806, 2510, 4140, 4610, 5020, 3700, 1690, 1270, 1190, 585, 543, 945,
	780, 1280, 3880, 6580, 6460, 3930, 2350, 1620, 1040, 643, 589, 543, 482,
	767, 4170, 7880, 6510, 3720, 2130, 2100, 1940, 1590, 1660, 1140, 964, 
	2020, 5290, 7970, 6960, 4320, 2570, 1650, 1180, 837, 668, 584, 497, 
	1360, 4050, 6470, 6930, 4640, 2420, 1430, 1320, 1160, 1010, 834, 648, 
	857, 3980, 7240, 9600, 5460, 3130, 3310, 1860, 1200, 935, 899, 824, 
	1580, 5330, 9320, 6610, 4230, 2710, 2700, 1940, 1360, 908, 677, 590, 
	848, 4030, 8130, 5430, 3450, 2510, 2300, 1310, 1170, 906, 674, 612, 
	1410, 4830, 7830, 5670, 3490, 2500, 1290, 939, 841, 579, 907, 715, 874, 
	6020, 6790, 5060, 3900, 3110, 1950, 1310, 1230, 869, 780, 702, 2230, 
	7060, 7020, 4810, 3020, 2360, 1140, 894, 1700, 1240, 857, 939, 2710, 
	4810, 4390, 4300, 2500, 1580, 1450, 1270, 882, 787, 633, 573, 896, 3320,
	7360, 5880, 3610, 2510, 2920, 1730, 1030, 1050, 781, 810, 1550, 6470, 
	7440, 5810, 3230, 1780, 1300, 860, 540, 520, 497, 505, 676, 2750, 6180, 
	4150, 2970, 1890, 1340, 986, 793, 975, 799, 635, 1810, 3510, 6220, 5370,
	3130, 2180, 1430, 1160, 840, 772, 709, 750, 1120, 4280, 6100, 5210, 
	2950, 2180, 1950, 1380, 871, 721, 772, 935, 2120, 5470, 7160, 5160, 
	3920, 2370, 1690, 1790, 1440, 989, 754, 675, 1250, 5090, 7940, 7950, 
	5160, 2850, 2070, 2820, 1710, 1350, 1370, 1250, 3380, 6510, 6570, 4730, 
	3480, 2610, 2420, 2400, 1350, 1240, 1560, 1090, 1220, 4600, 7010, 6340, 
	3540, 2260, 1570, 1250, 1030, 752, 696, 662, 1680, 6060, 7170, 4930, 
	2970, 2150, 2050, 1900, 1360, 618, 528, 637, 1340, 3880, 6730, 5090, 
	3180, 2450, 1660, 1760, 1010, 823, 633, 701, 1380, 3690, 5590, 4170, 
	2380, 2060, 1380, 910, 744, 728, 579, 714, 2130, 5740, 6340, 5400, 3460,
	2220, 2100, 2050, 2420, 1110, 909, 976, 2360, 4860, 5900, 4880, 3380, 
	2380, 1870, 1230, 917, 809, 791, 842, 2370, 3530, 4580, 3960, 2670, 
	2630, 3410, 2230, 1690, 983, 776, 665, 1350, 3550, 6040, 4770, 3160, 
	1890, 1570, 1120, 962, 799, 766, 654, 2170, 3140, 5770, 5800, 3510, 
	2030, 1470, 994, 707, 666, 612, 613, 1580, 3290, 5390, 3650, 3210, 2480,
	2250, 1680, 1050, 870, 747, 644, 904, 4110, 6700, 4250, 2580, 1740, 
	1340, 1020, 764, 656, 587, 660, 1150, 6130, 7480, 5330, 3210, 1800, 
	1030, 727, 675, 589, 596, 715, 2070, 5460, 7170, 5410, 3200, 2120, 2070,
	1540, 1050, 954, 693, 632, 968, 6550, 10700, 5130, 4600, 3460, 2490, 
	1610, 829, 672, 649, 691, 2150, 6380, 6140, 4090, 3440, 2100, 1490, 
	1810, 1200, 726, 699, 667, 952, 4160, 8880, 6650, 3330, 2120, 1580, 
	1550, 1310, 874, 774, 659, 1650, 6040, 6020, 5040, 2760, 1550, 1230, 
	1100, 793, 731, 676, 596, 1700, 5670, 6790, 5840, 3260, 1890, 1540, 921,
	624, 660, 706, 610, 920, 4960, 6020, 4840, 2850, 2330, 1970, 2000, 1240,
	843, 939, 775, 796, 4100, 7600, 7170, 4460, 3290, 2490, 2640, 1800, 
	1100, 918, 741, 1280, 3520, 7950, 7900, 4430, 2160, 1600, 1260, 869, 
	730, 639, 617, 1700, 5800, 7740, 4950, 2780, 1930, 1870, 1410, 1030, 
	1210, 1160, 932, 1510, 8170, 6820, 4550, 3390, 2550, 1590, 1700, 1500, 
	1310, 1180, 1260, 2450, 6390, 7430, 4340, 2740, 2260, 2820, 1610, 1360, 
	1120, 835, 815, 1560, 4830, 7460, 6350, 3630, 4010, 3410, 2830, 1860, 
	1210, 1060, 999, 2530, 4390, 6980, 7020, 3690, 2960, 2780, 2080, 1260, 
	1180, 1020, 1010, 2110, 5250, 7790, 4430, 2970, 2690, 2700, 1720, 906, 
	991, 1420, 808, 2380, 4150, 6970, 6100, 4490, 2710, 2510, 2710, 1770, 
	1300, 1620, 1460, 2130, 4420, 6670, 5200, 3580, 2870, 2320, 1630, 1300, 
	1100, 1000, 880, 1490, 3990, 10200, 7810, 5030, 3360, 3460, 2190, 1310, 
	1120, 1100, 1090, 2100, 5220, 7400, 5050, 3620, 2230, 2290, 1950, 1190, 
	886, 856, 876, 2450, 5290, 7030, 5910, 3830, 2510, 2370, 1680, 1520, 
	1160, 1100, 966, 1340, 5420, 9960, 6560, 3590, 2370, 2060, 2020, 1250, 
	1520, 1450, 1830, 1760, 5230, 7890, 7210, 3770, 3090, 2430, 2280, 1340, 
	1030, 985, 897, 2330, 5150, 6520, 4140, 3160, 2740, 2500, 2010, 1480, 
	1010, 1010, 959, 1410, 3630, 6560, 3780, 2420, 1810, 1530, 1020, 809, 
	855, 1030, 841, 1550, 6120, 7590, 5590, 3570, 2360, 1890, 1550, 908, 
	774, 857, 1500, 2100, 6450, 10800, 7330, 4120, 2280, 1940, 1500, 1000, 
	984, 842, 850, 1550, 4910, 6180, 5000, 2930, 1680, 2080, 1620, 1130, 
	987, 929, 927, 2320, 5890, 8430, 7470, 4360, 2440, 1930, 1290, 978, 797,
	780, 736, 1100, 3940, 6830, 6070, 3420, 2300, 1950, 2360, 1480, 1140, 
	1030, 924, 2300, 7070, 7250, 7670, 6440, 4460, 2510, 1800, 1480, 1240, 
	1230, 1130, 2350, 4710, 5670, 4830, 3620, 2340, 1650, 1260, 1030, 881, 
	791, 952, 1960, 3950, 5730, 4540, 2970, 2600, 2090, 1590, 1010, 801, 
	721, 957, 1290, 4910, 6360, 4860, 2610, 1830, 1420, 918, 952, 684, 649, 
	703, 1760, 5120, 4900, 4010, 2720, 2600, 2080, 1630, 1900, 1860, 1480, 
	1300, 1880, 4950, 6260, 4890, 3620, 2130, 1530, 1950, 1140, 821, 927, 
	844, 1010, 5360, 8690, 7230, 4850, 3620, 2310, 1470, 1110, 972, 977, 
	1240, 1990, 4090, 6060, 5240, 3460, 2210, 1470, 2050, 878, 1160, 1010, 
	1160, 2030, 2870, 6370, 6580, 3780, 2920, 2560, 1370, 861, 740, 706, 
	801, 2070, 5300, 7390, 4650, 2770, 1940, 1980, 1230, 746, 813, 809, 
	1280, 2090, 3770, 8390, 5380, 3220, 1890, 1470, 1340, 908, 1000, 944, 
	1300, 2280, 5120, 5840, 4070, 2980, 1680, 1020, 1210, 811, 629, 657, 
	809, 2410, 5450, 5940, 4430, 3010, 1890, 1540, 1470, 926, 800, 685, 682,
	1780, 4860, 6020, 3990, 3170, 1840, 1380, 2060, 1410, 1210, 841, 926, 
	3000, 5050, 8760, 6270, 3340, 1790, 1520, 2110, 1190), .Tsp = c(
	1913.1666666666667, 1991.9166666666667, 12), period.abb = c("Jan", 
	"Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", 
	"Dec"), title = 
	"Fraser River at Hope, mean monthly flow (cms),  1912.3-1991.12")

==> pear_0.1-4.tar.gz: pear/data/fraser.R <==
"fraser"<-
structure(.Data = c(485, 1150, 4990, 6130, 4780, 3960, 2160, 1530, 1060, 761, 
	516, 710, 570, 984, 2690, 8280, 6480, 5990, 3930, 1760, 1010, 736, 1050,
	787, 906, 2100, 5730, 7140, 6530, 3720, 2140, 1970, 1760, 1080, 886, 
	749, 806, 2510, 4140, 4610, 5020, 3700, 1690, 1270, 1190, 585, 543, 945,
	780, 1280, 3880, 6580, 6460, 3930, 2350, 1620, 1040, 643, 589, 543, 482,
	767, 4170, 7880, 6510, 3720, 2130, 2100, 1940, 1590, 1660, 1140, 964, 
	2020, 5290, 7970, 6960, 4320, 2570, 1650, 1180, 837, 668, 584, 497, 
	1360, 4050, 6470, 6930, 4640, 2420, 1430, 1320, 1160, 1010, 834, 648, 
	857, 3980, 7240, 9600, 5460, 3130, 3310, 1860, 1200, 935, 899, 824, 
	1580, 5330, 9320, 6610, 4230, 2710, 2700, 1940, 1360, 908, 677, 590, 
	848, 4030, 8130, 5430, 3450, 2510, 2300, 1310, 1170, 906, 674, 612, 
	1410, 4830, 7830, 5670, 3490, 2500, 1290, 939, 841, 579, 907, 715, 874, 
	6020, 6790, 5060, 3900, 3110, 1950, 1310, 1230, 869, 780, 702, 2230, 
	7060, 7020, 4810, 3020, 2360, 1140, 894, 1700, 1240, 857, 939, 2710, 
	4810, 4390, 4300, 2500, 1580, 1450, 1270, 882, 787, 633, 573, 896, 3320,
	7360, 5880, 3610, 2510, 2920, 1730, 1030, 1050, 781, 810, 1550, 6470, 
	7440, 5810, 3230, 1780, 1300, 860, 540, 520, 497, 505, 676, 2750, 6180, 
	4150, 2970, 1890, 1340, 986, 793, 975, 799, 635, 1810, 3510, 6220, 5370,
	3130, 2180, 1430, 1160, 840, 772, 709, 750, 1120, 4280, 6100, 5210, 
	2950, 2180, 1950, 1380, 871, 721, 772, 935, 2120, 5470, 7160, 5160, 
	3920, 2370, 1690, 1790, 1440, 989, 754, 675, 1250, 5090, 7940, 7950, 
	5160, 2850, 2070, 2820, 1710, 1350, 1370, 1250, 3380, 6510, 6570, 4730, 
	3480, 2610, 2420, 2400, 1350, 1240, 1560, 1090, 1220, 4600, 7010, 6340, 
	3540, 2260, 1570, 1250, 1030, 752, 696, 662, 1680, 6060, 7170, 4930, 
	2970, 2150, 2050, 1900, 1360, 618, 528, 637, 1340, 3880, 6730, 5090, 
	3180, 2450, 1660, 1760, 1010, 823, 633, 701, 1380, 3690, 5590, 4170, 
	2380, 2060, 1380, 910, 744, 728, 579, 714, 2130, 5740, 6340, 5400, 3460,
	2220, 2100, 2050, 2420, 1110, 909, 976, 2360, 4860, 5900, 4880, 3380, 
	2380, 1870, 1230, 917, 809, 791, 842, 2370, 3530, 4580, 3960, 2670, 
	2630, 3410, 2230, 1690, 983, 776, 665, 1350, 3550, 6040, 4770, 3160, 
	1890, 1570, 1120, 962, 799, 766, 654, 2170, 3140, 5770, 5800, 3510, 
	2030, 1470, 994, 707, 666, 612, 613, 1580, 3290, 5390, 3650, 3210, 2480,
	2250, 1680, 1050, 870, 747, 644, 904, 4110, 6700, 4250, 2580, 1740, 
	1340, 1020, 764, 656, 587, 660, 1150, 6130, 7480, 5330, 3210, 1800, 
	1030, 727, 675, 589, 596, 715, 2070, 5460, 7170, 5410, 3200, 2120, 2070,
	1540, 1050, 954, 693, 632, 968, 6550, 10700, 5130, 4600, 3460, 2490, 
	1610, 829, 672, 649, 691, 2150, 6380, 6140, 4090, 3440, 2100, 1490, 
	1810, 1200, 726, 699, 667, 952, 4160, 8880, 6650, 3330, 2120, 1580, 
	1550, 1310, 874, 774, 659, 1650, 6040, 6020, 5040, 2760, 1550, 1230, 
	1100, 793, 731, 676, 596, 1700, 5670, 6790, 5840, 3260, 1890, 1540, 921,
	624, 660, 706, 610, 920, 4960, 6020, 4840, 2850, 2330, 1970, 2000, 1240,
	843, 939, 775, 796, 4100, 7600, 7170, 4460, 3290, 2490, 2640, 1800, 
	1100, 918, 741, 1280, 3520, 7950, 7900, 4430, 2160, 1600, 1260, 869, 
	730, 639, 617, 1700, 5800, 7740, 4950, 2780, 1930, 1870, 1410, 1030, 
	1210, 1160, 932, 1510, 8170, 6820, 4550, 3390, 2550, 1590, 1700, 1500, 
	1310, 1180, 1260, 2450, 6390, 7430, 4340, 2740, 2260, 2820, 1610, 1360, 
	1120, 835, 815, 1560, 4830, 7460, 6350, 3630, 4010, 3410, 2830, 1860, 
	1210, 1060, 999, 2530, 4390, 6980, 7020, 3690, 2960, 2780, 2080, 1260, 
	1180, 1020, 1010, 2110, 5250, 7790, 4430, 2970, 2690, 2700, 1720, 906, 
	991, 1420, 808, 2380, 4150, 6970, 6100, 4490, 2710, 2510, 2710, 1770, 
	1300, 1620, 1460, 2130, 4420, 6670, 5200, 3580, 2870, 2320, 1630, 1300, 
	1100, 1000, 880, 1490, 3990, 10200, 7810, 5030, 3360, 3460, 2190, 1310, 
	1120, 1100, 1090, 2100, 5220, 7400, 5050, 3620, 2230, 2290, 1950, 1190, 
	886, 856, 876, 2450, 5290, 7030, 5910, 3830, 2510, 2370, 1680, 1520, 
	1160, 1100, 966, 1340, 5420, 9960, 6560, 3590, 2370, 2060, 2020, 1250, 
	1520, 1450, 1830, 1760, 5230, 7890, 7210, 3770, 3090, 2430, 2280, 1340, 
	1030, 985, 897, 2330, 5150, 6520, 4140, 3160, 2740, 2500, 2010, 1480, 
	1010, 1010, 959, 1410, 3630, 6560, 3780, 2420, 1810, 1530, 1020, 809, 
	855, 1030, 841, 1550, 6120, 7590, 5590, 3570, 2360, 1890, 1550, 908, 
	774, 857, 1500, 2100, 6450, 10800, 7330, 4120, 2280, 1940, 1500, 1000, 
	984, 842, 850, 1550, 4910, 6180, 5000, 2930, 1680, 2080, 1620, 1130, 
	987, 929, 927, 2320, 5890, 8430, 7470, 4360, 2440, 1930, 1290, 978, 797,
	780, 736, 1100, 3940, 6830, 6070, 3420, 2300, 1950, 2360, 1480, 1140, 
	1030, 924, 2300, 7070, 7250, 7670, 6440, 4460, 2510, 1800, 1480, 1240, 
	1230, 1130, 2350, 4710, 5670, 4830, 3620, 2340, 1650, 1260, 1030, 881, 
	791, 952, 1960, 3950, 5730, 4540, 2970, 2600, 2090, 1590, 1010, 801, 
	721, 957, 1290, 4910, 6360, 4860, 2610, 1830, 1420, 918, 952, 684, 649, 
	703, 1760, 5120, 4900, 4010, 2720, 2600, 2080, 1630, 1900, 1860, 1480, 
	1300, 1880, 4950, 6260, 4890, 3620, 2130, 1530, 1950, 1140, 821, 927, 
	844, 1010, 5360, 8690, 7230, 4850, 3620, 2310, 1470, 1110, 972, 977, 
	1240, 1990, 4090, 6060, 5240, 3460, 2210, 1470, 2050, 878, 1160, 1010, 
	1160, 2030, 2870, 6370, 6580, 3780, 2920, 2560, 1370, 861, 740, 706, 
	801, 2070, 5300, 7390, 4650, 2770, 1940, 1980, 1230, 746, 813, 809, 
	1280, 2090, 3770, 8390, 5380, 3220, 1890, 1470, 1340, 908, 1000, 944, 
	1300, 2280, 5120, 5840, 4070, 2980, 1680, 1020, 1210, 811, 629, 657, 
	809, 2410, 5450, 5940, 4430, 3010, 1890, 1540, 1470, 926, 800, 685, 682,
	1780, 4860, 6020, 3990, 3170, 1840, 1380, 2060, 1410, 1210, 841, 926, 
	3000, 5050, 8760, 6270, 3340, 1790, 1520, 2110, 1190), .Tsp = c(
	1913.1666666666667, 1991.9166666666667, 12), period.abb = c("Jan", 
	"Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", 
	"Dec"), title = 
	"Fraser River at Hope, mean monthly flow (cms),  1912.3-1991.12", class="ts")
